@@ -50,7 +50,6 @@ class TestConnectors(BaseTest):
             ("combination/connector_event_rule_to_eb_custom_write",),
             ("combination/connector_event_rule_to_lambda_write",),
             ("combination/connector_event_rule_to_lambda_write_multiple",),
-            ("combination/connector_function_to_location_place_index",),
             ("combination/connector_mix_destination",),
             ("combination/connector_sqs_to_function",),
             ("combination/connector_sns_to_function_write",),
@@ -75,6 +74,30 @@ class TestConnectors(BaseTest):
         self.assertEqual(response.get("StatusCode"), 200)
         self.assertEqual(response.get("FunctionError"), None)
 
+    @parameterized.expand(
+        [
+            ("combination/connector_function_to_location_place_index",),
+        ]
+    )
+    @retry_once
+    def test_connector_by_invoking_a_function_with_parameters(self, template_file_path):
+        parameters = []
+        parameters.append(self.generate_parameter("IndexName", f"PlaceIndex-{generate_suffix()}"))
+        self.skip_using_service_detector(template_file_path)
+        self.create_and_verify_stack(template_file_path, parameters)
+
+        lambda_function_name = self.get_physical_id_by_logical_id("TriggerFunction")
+        lambda_client = self.client_provider.lambda_client
+
+        request_params = {
+            "FunctionName": lambda_function_name,
+            "InvocationType": "RequestResponse",
+            "Payload": "{}",
+        }
+        response = lambda_client.invoke(**request_params)
+        self.assertEqual(response.get("StatusCode"), 200)
+        self.assertEqual(response.get("FunctionError"), None)
+
     @parameterized.expand(
         [
             ("combination/connector_sfn_to_function_without_policy",),
